package com.speedingplanet.banking.core;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonProperty;
import org.joda.time.DateTime;

import javax.persistence.*;

@SuppressWarnings("JpaQlInspection")
@Entity
@Table(name = "transactions")
@NamedQueries({
    @NamedQuery(
        name = "com.speedingplanet.banking.core.Transaction.findAll",
        query = "SELECT tx from Transaction tx"
    )
})
public class Transaction {

  public Transaction() {
  }

  public Transaction(int txId, DateTime txDate) {
    this.txId = txId;
    this.txDate = txDate;
  }

  public Transaction(int txId, int categoryId, int accountId, String txType,
                     int payeeId, String txStatus, DateTime txDate, double amount) {
    this.txId = txId;
    this.categoryId = categoryId;
    this.accountId = accountId;
    this.txType = txType;
    this.payeeId = payeeId;
    this.txStatus = txStatus;
    this.txDate = txDate;
    this.amount = amount;
  }

  @Id
  @GeneratedValue(strategy = GenerationType.IDENTITY)
  @JsonProperty
  private int txId;

  @Column(name = "payeeId", nullable = false)
  @JsonProperty
  private int payeeId;

  @Column(name = "amount", nullable = false)
  @JsonProperty
  private double amount;

  @Column(name = "txType", nullable = false)
  @JsonProperty
  private String txType;

  @Column(name = "txStatus", nullable = false)
  @JsonProperty
  private String txStatus;

  @Column(name = "txDate", nullable = false)
  @JsonProperty
  @JsonFormat
      (shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd'T'HH:mm:ss.SSS")
  private DateTime txDate;

  @Column(name = "accountId", nullable = false)
  @JsonProperty
  private int accountId;

  @Column(name = "categoryId", nullable = false)
  @JsonProperty
  private int categoryId;

  public int getTxId() {
    return txId;
  }

  public int getPayeeId() {
    return payeeId;
  }

  public double getAmount() {
    return amount;
  }

  public String getTxType() {
    return txType;
  }

  public String getTxStatus() {
    return txStatus;
  }

  public DateTime getTxDate() {
    return txDate;
  }

  public int getAccountId() {
    return accountId;
  }

  public int getCategoryId() {
    return categoryId;
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) return true;
    if (!(o instanceof Transaction)) return false;

    Transaction that = (Transaction) o;

    return this.getTxId() == that.getTxId();
  }

  @Override
  public int hashCode() {
    return txId;
  }
}
