package com.speedingplanet.banking.db;

import com.speedingplanet.banking.api.Transaction;
import io.dropwizard.hibernate.AbstractDAO;
import org.hibernate.Criteria;
import org.hibernate.SessionFactory;
import org.hibernate.criterion.Restrictions;
import org.joda.time.DateTime;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.ws.rs.core.MultivaluedMap;
import java.util.List;

public class TransactionDAO extends AbstractDAO<Transaction> {
  private static final Logger LOGGER = LoggerFactory.getLogger(TransactionDAO.class);
  public TransactionDAO(SessionFactory sessionFactory) {
    super(sessionFactory);
  }

  public Transaction findById(Integer id) {
    return get(id);
  }

  public Transaction update(Transaction tx) {
    return persist(tx);
  }

  public Transaction create(Transaction tx) {
    return persist(tx);
  }

  public List<Transaction> findAll() {
    return list(namedQuery("com.speedingplanet.banking.api.Transaction.findAll"));
  }

  public List<Transaction> findByPayeeName(String payeeName) {
    LOGGER.info(String.format("TransactionDAO.findByPayeeName(): [%s]", payeeName));
    return list(namedQuery("com.speedingplanet.banking.api.Transaction.findByPayeeName").setString("payeeName", payeeName));
  }

  public List<Transaction> query(MultivaluedMap<String, String> queryParams) {
    Criteria c = criteria();

    // Assumes, for the moment, that keys are singular, not multiples
    for (String key : queryParams.keySet()) {
      switch (key) {
        case "txId":
        case "payeeId":
        case "accountId":
        case "categoryId":
          c.add(Restrictions.eq(key, Integer.parseInt(queryParams.getFirst(key))));
          break;
        case "amount":
          c.add(Restrictions.eq(key, Double.parseDouble(queryParams.getFirst(key))));
          break;
        case "txDate":
          // Assumes that the key passed is an ISO8601-format String
          c.add(Restrictions.eq(key, new DateTime(queryParams.getFirst(key))));
          break;
        default:
          c.add(Restrictions.eq(key, queryParams.getFirst(key)));
          break;
      }
    }

    return list(c);
  }
}
