package com.speedingplanet.banking;

import com.speedingplanet.banking.api.Transaction;
import io.dropwizard.client.JerseyClientBuilder;
import io.dropwizard.testing.ResourceHelpers;
import io.dropwizard.testing.junit.DropwizardAppRule;
import org.junit.*;

import javax.ws.rs.client.Client;
import javax.ws.rs.client.WebTarget;
import javax.ws.rs.core.Response;

import static org.assertj.core.api.Assertions.assertThat;

public class TransactionIntegrationTest {
  private WebTarget baseTarget;
  private Client client;

  // Multiple tests (below) means that this should be a Rule, not a ClassRule
  // per https://github.com/dropwizard/dropwizard/issues/832
  @Rule
  public final DropwizardAppRule<BankingConfiguration> RULE =
      new DropwizardAppRule<>(BankingApplication.class, ResourceHelpers.resourceFilePath("test-config.yml"));

  @Before
  public void setup() {
    client = new JerseyClientBuilder(RULE.getEnvironment()).build("test client");
    baseTarget = client.target(String.format("http://localhost:%d/banking", RULE.getLocalPort()));
  }

  @After
  public void shutdown() {
    client.close();
  }

  @Test
  public void checkBankingStatus() {
    Response response = baseTarget.path("hello").request().get();

    assertThat(response.getStatus()).isEqualTo(200);
    assertThat(response.readEntity(String.class)).isEqualTo("Hello, the server is running.");
  }

  @Test
  public void checkGetOneTx() {
    Response response = baseTarget.path("tx/1").request().get();

    assertThat(response.getStatus()).isEqualTo(200);
    assertThat(response.readEntity(Transaction.class).getTxId()).isEqualTo(1);
  }

}
