package com.speedingplanet.equities;

import com.fasterxml.jackson.databind.SerializationFeature;
import com.speedingplanet.equities.api.Order;
import com.speedingplanet.equities.api.Position;
import com.speedingplanet.equities.api.Price;
import com.speedingplanet.equities.api.Security;
import com.speedingplanet.equities.db.OrderDAO;
import com.speedingplanet.equities.db.PositionDAO;
import com.speedingplanet.equities.db.PriceDAO;
import com.speedingplanet.equities.db.SecurityDAO;
import com.speedingplanet.equities.resources.OrderResource;
import com.speedingplanet.equities.resources.PositionResource;
import com.speedingplanet.equities.resources.PriceResource;
import com.speedingplanet.equities.resources.SecurityResource;
import io.dropwizard.Application;
import io.dropwizard.db.DataSourceFactory;
import io.dropwizard.hibernate.HibernateBundle;
import io.dropwizard.setup.Bootstrap;
import io.dropwizard.setup.Environment;
import org.eclipse.jetty.servlets.CrossOriginFilter;
import org.glassfish.jersey.filter.LoggingFilter;

import javax.servlet.DispatcherType;
import javax.servlet.FilterRegistration;
import java.util.EnumSet;
import java.util.logging.Logger;

public class StocksApplication extends Application<StocksConfiguration> {
  public static void main(final String[] args) throws Exception {
    new StocksApplication().run(args);
  }

  @Override
  public String getName() {
    return "Stocks";
  }

  private final HibernateBundle<StocksConfiguration> hibernateBundle =
      new HibernateBundle<StocksConfiguration>(Security.class, Price.class, Position.class, Order.class) {
        @Override
        public DataSourceFactory getDataSourceFactory(StocksConfiguration configuration) {
          return configuration.getDataSourceFactory();
        }
      };

  @Override
  public void initialize(final Bootstrap<StocksConfiguration> bootstrap) {
    bootstrap.addBundle(hibernateBundle);
  }

  @Override
  public void run(final StocksConfiguration configuration,
                  final Environment environment) {
    configureCors(environment);

    // Pretty-print JSON
    environment.getObjectMapper().enable(SerializationFeature.INDENT_OUTPUT);

    // Logs any incoming request bodies at the INFO level
    environment.jersey().register(new LoggingFilter(Logger.getLogger("InboundRequestResponse"), true));

    final SecurityDAO secDAO = new SecurityDAO(hibernateBundle.getSessionFactory());
    environment.jersey().register(new SecurityResource(secDAO));

    final PriceDAO priceDAO = new PriceDAO(hibernateBundle.getSessionFactory());
    environment.jersey().register(new PriceResource(priceDAO));

    final PositionDAO positionDAO = new PositionDAO(hibernateBundle.getSessionFactory());
    environment.jersey().register(new PositionResource(positionDAO));

    final OrderDAO orderDAO = new OrderDAO(hibernateBundle.getSessionFactory());
    environment.jersey().register(new OrderResource(orderDAO));
  }

  private void configureCors(Environment environment) {
    FilterRegistration.Dynamic filter = environment.servlets().addFilter("CORS", new CrossOriginFilter());
    filter.setInitParameter("allowedOrigins", "*");
    filter.setInitParameter("allowedHeaders", "*");
    filter.setInitParameter("allowedHeaders", "*");
    filter.addMappingForUrlPatterns(EnumSet.allOf(DispatcherType.class), true, "/*");
  }

}
