package com.speedingplanet.equities.api;

import com.fasterxml.jackson.annotation.JsonFormat;
import org.joda.time.DateTime;

import javax.persistence.*;
import javax.validation.constraints.NotNull;

@Entity
@Table(name = "orders")
@NamedQueries({
    @NamedQuery(
        name = "com.speedingplanet.equities.api.Order.findAll",
        query = "SELECT o from Order o"
    )
})
public class Order {

  @Id
  @GeneratedValue(strategy = GenerationType.IDENTITY)
  private int orderId;


  @NotNull
  private String symbol;

  @JsonFormat
      (shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd")
  private DateTime orderDate;

  @NotNull
  private int quantity;

  @NotNull
  private double price;

  public Order() {}

  public Order(String symbol, DateTime orderDate, int quantity, double price) {
    this.symbol = symbol;
    this.orderDate = orderDate;
    this.quantity = quantity;
    this.price = price;
  }

  public int getOrderId() {
    return orderId;
  }

  public String getSymbol() {
    return symbol;
  }

  public DateTime getOrderDate() {
    return orderDate;
  }

  public int getQuantity() {
    return quantity;
  }

  public double getPrice() {
    return price;
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) return true;
    if (!(o instanceof Order)) return false;

    Order order = (Order) o;

    if (getOrderId() != order.getOrderId()) return false;
    if (getQuantity() != order.getQuantity()) return false;
    if (Double.compare(order.getPrice(), getPrice()) != 0) return false;
    if (!getSymbol().equals(order.getSymbol())) return false;
    return getOrderDate().equals(order.getOrderDate());

  }

  @Override
  public int hashCode() {
    int result;
    long temp;
    result = getOrderId();
    result = 31 * result + getSymbol().hashCode();
    result = 31 * result + getOrderDate().hashCode();
    result = 31 * result + getQuantity();
    temp = Double.doubleToLongBits(getPrice());
    result = 31 * result + (int) (temp ^ (temp >>> 32));
    return result;
  }
}
