package com.speedingplanet.equities.api;

import com.fasterxml.jackson.annotation.JsonFormat;
import org.joda.time.DateTime;

import javax.persistence.*;
import javax.validation.constraints.NotNull;

@Entity
@Table(name = "prices")
@NamedQueries({
    @NamedQuery(
        name = "com.speedingplanet.equities.api.Price.findAll",
        query = "SELECT p from Price p"
    )
})
public class Price {

  @Id
  @GeneratedValue(strategy = GenerationType.IDENTITY)
  private int priceId;

  @NotNull
  private String symbol;

  @JsonFormat
      (shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd")
  private DateTime priceDate;

  @NotNull
  private double open;

  @NotNull
  private double high;

  @NotNull
  private double low;

  @NotNull
  private double close;

  @NotNull
  private int volume;

  @NotNull
  private double adjustedClose;

  public Price() {}

  public Price(String symbol, DateTime priceDate, double open, double high, double low, double close, int volume, double adjustedClose) {
    this.symbol = symbol;
    this.priceDate = priceDate;
    this.open = open;
    this.high = high;
    this.low = low;
    this.close = close;
    this.volume = volume;
    this.adjustedClose = adjustedClose;
  }

  public int getPriceId() {
    return priceId;
  }

  public String getSymbol() {
    return symbol;
  }

  public DateTime getPriceDate() {
    return priceDate;
  }

  public double getOpen() {
    return open;
  }

  public double getHigh() {
    return high;
  }

  public double getLow() {
    return low;
  }

  public double getClose() {
    return close;
  }

  public int getVolume() {
    return volume;
  }

  public double getAdjustedClose() {
    return adjustedClose;
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) return true;
    if (!(o instanceof Price)) return false;

    Price price = (Price) o;

    if (getPriceId() != price.getPriceId()) return false;
    if (Double.compare(price.getOpen(), getOpen()) != 0) return false;
    if (!getSymbol().equals(price.getSymbol())) return false;
    return getPriceDate().equals(price.getPriceDate());

  }

  @Override
  public int hashCode() {
    int result;
    long temp;
    result = getPriceId();
    result = 31 * result + getSymbol().hashCode();
    result = 31 * result + getPriceDate().hashCode();
    temp = Double.doubleToLongBits(getOpen());
    result = 31 * result + (int) (temp ^ (temp >>> 32));
    return result;
  }
}
