package com.speedingplanet.equities.resources;

import com.google.common.base.Optional;
import com.speedingplanet.equities.api.Price;
import com.speedingplanet.equities.db.PriceDAO;
import io.dropwizard.hibernate.UnitOfWork;

import javax.ws.rs.*;
import javax.ws.rs.core.*;
import java.util.List;

@Path("/price")
@Produces(MediaType.APPLICATION_JSON)
@Consumes(MediaType.APPLICATION_JSON)
public class PriceResource {
  private final PriceDAO priceDAO;

  public PriceResource(PriceDAO priceDAO) {
    this.priceDAO = priceDAO;
  }

  // We're not defining a generic getPrices because there are too many records for that!

  @Path("/{priceId:[0-9]+}")
  @GET
  @UnitOfWork
  public Price getPrice(@PathParam("priceId") int priceId) {
    Optional<Price> price = Optional.fromNullable(priceDAO.findById(priceId));

    if (!price.isPresent()) {
      throw new NotFoundException(String.format("Price for priceId %d not found.", priceId));
    }

    return price.get();
  }

  @Path("/{symbol:[A-Z]{1,6}}")
  @GET
  @UnitOfWork
  public List<Price> getPriceBySymbol(@PathParam("symbol") String symbol) {
    MultivaluedMap<String, String> query = new MultivaluedHashMap<String, String>();
    query.add("symbol", symbol);
    return priceDAO.query(query);
  }

  @GET
  @UnitOfWork
  public List<Price> getPrices(@Context UriInfo uriInfo) {
    MultivaluedMap<String, String> queryParams = uriInfo.getQueryParameters();

    if (queryParams.size() == 0) {
      throw new WebApplicationException(
          "You must include some query parameters (symbol, startDate, endDate, priceLow, priceHigh)",
          Response.Status.BAD_REQUEST
      );
    } else {
      List<Price> prices = priceDAO.query(queryParams);
      if (prices.size() == 0) {
        throw new NotFoundException("Could not find any prices which match the query information.");
      }
      return prices;
    }
  }
}