package com.speedingplanet.equities.resources;

import com.google.common.base.Optional;
import com.speedingplanet.equities.api.Security;
import com.speedingplanet.equities.db.SecurityDAO;
import io.dropwizard.hibernate.UnitOfWork;

import javax.validation.Valid;
import javax.ws.rs.*;
import javax.ws.rs.core.Context;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;
import javax.ws.rs.core.UriInfo;
import java.net.URI;
import java.util.List;

@Path("/security")
@Produces(MediaType.APPLICATION_JSON)
@Consumes(MediaType.APPLICATION_JSON)
public class SecurityResource {
  private final SecurityDAO secDAO;

  @Context
  UriInfo uriInfo;

  public SecurityResource(SecurityDAO secDAO) {
    this.secDAO = secDAO;
  }

  @GET
  @UnitOfWork
  public List<Security> getSecurities() {
    return this.secDAO.findAll();
  }

  @Path("/{symbol:[A-Z]{1,6}}")
  @GET
  @UnitOfWork
  public Security getSecurity(@PathParam("symbol") String symbol) {
    Optional<Security> security = Optional.fromNullable(secDAO.findBySymbol(symbol));

    if (!security.isPresent()) {
      throw new NotFoundException(String.format("Security with symbol '%s' not found.", symbol));
    } else {
      return security.get();
    }
  }

  @POST
  @UnitOfWork
  public Response insertSecurity(@Valid Security sec) {
    Security responseSec = secDAO.create(sec);
    URI uri = uriInfo
        .getBaseUriBuilder()
        .path(SecurityResource.class)
        .path("" + responseSec.getSymbol())
        .build();
    return Response.created(uri).entity(responseSec).build();
  }

  @Path("/{symbol:[A-Z]{1,6}}")
  @POST
  @UnitOfWork
  public Response updateSecurity(Security sec) {
    return Response.ok(secDAO.update(sec)).build();
  }

  @Path("/{symbol:[A-Z]{1,6}}")
  @PUT
  @UnitOfWork
  public Response putUpdateSecurity(Security sec) {
    return updateSecurity(sec);
  }
}
