DROP TABLE IF EXISTS securities;

CREATE TABLE securities (
  symbol       VARCHAR(10) PRIMARY KEY,
  securityName VARCHAR(255) NOT NULL,
);

DROP TABLE IF EXISTS prices;

CREATE TABLE prices (
  priceId       BIGINT PRIMARY KEY AUTO_INCREMENT,
  symbol        VARCHAR(10)    NOT NULL,
  priceDate     DATE           NOT NULL,
  open          DECIMAL(10, 6) NOT NULL,
  high          DECIMAL(10, 6) NOT NULL,
  low           DECIMAL(10, 6) NOT NULL,
  close         DECIMAL(10, 6) NOT NULL,
  volume        INT            NOT NULL,
  adjustedClose DECIMAL(10, 6) NOT NULL
);

DROP TABLE IF EXISTS positions;

CREATE TABLE positions (
  positionId  INT PRIMARY KEY         AUTO_INCREMENT,
  symbol      VARCHAR(10)    NOT NULL,
  quantity    INT            NOT NULL,
  boughtPrice DECIMAL(10, 6) NOT NULL,
  boughtDate  DATE           NOT NULL,
  soldPrice   DECIMAL(10, 6),
  soldDate    DATE,
  isActive    BOOLEAN        NOT NULL DEFAULT TRUE
);

DROP TABLE IF EXISTS orders;

CREATE TABLE orders (
  orderId   INT PRIMARY KEY AUTO_INCREMENT,
  orderDate DATE           NOT NULL,
  symbol    VARCHAR(10)    NOT NULL,
  quantity  INT            NOT NULL,
  price     DECIMAL(10, 6) NOT NULL
);

INSERT INTO securities (symbol, SECURITYNAME) VALUES ('AAPL', 'Apple Computer');
INSERT INTO securities (symbol, SECURITYNAME) VALUES ('ADBE', 'Adobe Systems');
INSERT INTO securities (symbol, SECURITYNAME) VALUES ('CMCSA', 'Comcast');
INSERT INTO securities (symbol, SECURITYNAME) VALUES ('CSCO', 'Cisco Systems');
INSERT INTO securities (symbol, SECURITYNAME) VALUES ('FB', 'Facebook');
INSERT INTO securities (symbol, SECURITYNAME) VALUES ('FOX', 'Twenty-First Century Fox');
INSERT INTO securities (symbol, SECURITYNAME) VALUES ('GOOG', 'Google (no, wait, Alphabet)');
INSERT INTO securities (symbol, SECURITYNAME) VALUES ('INTC', 'Intel Corporation');
INSERT INTO securities (symbol, SECURITYNAME) VALUES ('INTU', 'Intuit');
INSERT INTO securities (symbol, SECURITYNAME) VALUES ('MAR', 'Marriott International');
INSERT INTO securities (symbol, SECURITYNAME) VALUES ('QCOM', 'Qualcomm Incorporated');
INSERT INTO securities (symbol, SECURITYNAME) VALUES ('SBUX', 'Starbucks Coffee');
INSERT INTO securities (symbol, SECURITYNAME) VALUES ('SEAS', 'Setec Astronomy');
INSERT INTO securities (symbol, SECURITYNAME) VALUES ('VIAB', 'Viacom');
INSERT INTO securities (symbol, SECURITYNAME) VALUES ('YHOO', 'Yahoo');

INSERT INTO POSITIONS (SYMBOL, QUANTITY, BOUGHTPRICE, BOUGHTDATE, SOLDPRICE, SOLDDATE, ISACTIVE)
VALUES('AAPL', 100, 5, convert(parsedatetime('1/31/2005', 'm/d/yyyy'), date), null, null, true);

INSERT INTO POSITIONS (SYMBOL, QUANTITY, BOUGHTPRICE, BOUGHTDATE, SOLDPRICE, SOLDDATE, ISACTIVE)
VALUES('GOOG', 100, 215, convert(parsedatetime('1/31/2006', 'm/d/yyyy'), date), null, null, true);

INSERT INTO POSITIONS (SYMBOL, QUANTITY, BOUGHTPRICE, BOUGHTDATE, SOLDPRICE, SOLDDATE, ISACTIVE)
VALUES('SBUX', 100, 15.8, convert(parsedatetime('1/31/2007', 'm/d/yyyy'), date), null, null, true);

INSERT INTO POSITIONS (SYMBOL, QUANTITY, BOUGHTPRICE, BOUGHTDATE, SOLDPRICE, SOLDDATE, ISACTIVE)
VALUES('QCOM', 100, 35, convert(parsedatetime('1/31/2008', 'm/d/yyyy'), date), null, null, true);

INSERT INTO POSITIONS (SYMBOL, QUANTITY, BOUGHTPRICE, BOUGHTDATE, SOLDPRICE, SOLDDATE, ISACTIVE)
VALUES('INTU', 100, 21.4, convert(parsedatetime('1/30/2009', 'm/d/yyyy'), date), null, null, true);

INSERT INTO POSITIONS (SYMBOL, QUANTITY, BOUGHTPRICE, BOUGHTDATE, SOLDPRICE, SOLDDATE, ISACTIVE)
VALUES('MAR', 100, 23, convert(parsedatetime('1/29/2010', 'm/d/yyyy'), date), null, null, true);

INSERT INTO ORDERS (SYMBOL, QUANTITY, PRICE, ORDERDATE)
VALUES ('AAPL', 100, 5, convert(parsedatetime('1/31/2005', 'm/d/yyyy'), DATE));

INSERT INTO ORDERS (SYMBOL, QUANTITY, PRICE, ORDERDATE)
VALUES ('GOOG', 100, 215, convert(parsedatetime('1/31/2006', 'm/d/yyyy'), DATE));

INSERT INTO ORDERS (SYMBOL, QUANTITY, PRICE, ORDERDATE)
VALUES ('SBUX', 100, 15.8, convert(parsedatetime('1/31/2007', 'm/d/yyyy'), date));

INSERT INTO ORDERS (SYMBOL, QUANTITY, PRICE, ORDERDATE)
VALUES ('QCOM', 100, 35, convert(parsedatetime('1/31/2008', 'm/d/yyyy'), date));

INSERT INTO ORDERS (SYMBOL, QUANTITY, PRICE, ORDERDATE)
VALUES ('INTU', 100, 21.4, convert(parsedatetime('1/30/2009', 'm/d/yyyy'), date));

INSERT INTO ORDERS (SYMBOL, QUANTITY, PRICE, ORDERDATE)
VALUES ('MAR', 100, 23, convert(parsedatetime('1/29/2010', 'm/d/yyyy'), date));

INSERT INTO PRICES (SYMBOL, PRICEDATE, OPEN, HIGH, LOW, CLOSE, VOLUME, ADJUSTEDCLOSE)
  SELECT SYMBOL, convert(parsedatetime(pricedate, 'M/d/yyyy'), date) as PRICEDATE,
    OPEN, HIGH, LOW, CLOSE, VOLUME, ADJUSTEDCLOSE FROM csvread('C:/classes/JAX-RS/stocks-solutions/data/AAPL.csv');

INSERT INTO PRICES (SYMBOL, PRICEDATE, OPEN, HIGH, LOW, CLOSE, VOLUME, ADJUSTEDCLOSE)
  SELECT 'ADBE', convert(parsedatetime(date, 'M/d/yyyy'), date) as PRICEDATE,
    OPEN, HIGH, LOW, CLOSE, VOLUME, ADJCLOSE
  FROM csvread('C:/classes/JAX-RS/stocks-solutions/data/ADBE.csv');

INSERT INTO PRICES (SYMBOL, PRICEDATE, OPEN, HIGH, LOW, CLOSE, VOLUME, ADJUSTEDCLOSE)
  SELECT 'CMCSA', convert(parsedatetime(date, 'yyyy-M-d'), date) as PRICEDATE,
    OPEN, HIGH, LOW, CLOSE, VOLUME, ADJCLOSE
  FROM csvread('C:/classes/JAX-RS/stocks-solutions/data/CMCSA.csv');

INSERT INTO PRICES (SYMBOL, PRICEDATE, OPEN, HIGH, LOW, CLOSE, VOLUME, ADJUSTEDCLOSE)
  SELECT 'CSCO', convert(parsedatetime(date, 'yyyy-M-d'), date) as PRICEDATE,
    OPEN, HIGH, LOW, CLOSE, VOLUME, ADJCLOSE
  FROM csvread('C:/classes/JAX-RS/stocks-solutions/data/CSCO.csv');

INSERT INTO PRICES (SYMBOL, PRICEDATE, OPEN, HIGH, LOW, CLOSE, VOLUME, ADJUSTEDCLOSE)
  SELECT 'FB', convert(parsedatetime(date, 'yyyy-M-d'), date) as PRICEDATE,
    OPEN, HIGH, LOW, CLOSE, VOLUME, ADJCLOSE
  FROM csvread('C:/classes/JAX-RS/stocks-solutions/data/FB.csv');

INSERT INTO PRICES (SYMBOL, PRICEDATE, OPEN, HIGH, LOW, CLOSE, VOLUME, ADJUSTEDCLOSE)
  SELECT 'FOX', convert(parsedatetime(date, 'yyyy-M-d'), date) as PRICEDATE,
    OPEN, HIGH, LOW, CLOSE, VOLUME, ADJCLOSE
  FROM csvread('C:/classes/JAX-RS/stocks-solutions/data/FOX.csv');

INSERT INTO PRICES (SYMBOL, PRICEDATE, OPEN, HIGH, LOW, CLOSE, VOLUME, ADJUSTEDCLOSE)
  SELECT 'GOOG', convert(parsedatetime(date, 'yyyy-M-d'), date) as PRICEDATE,
    OPEN, HIGH, LOW, CLOSE, VOLUME, ADJCLOSE
  FROM csvread('C:/classes/JAX-RS/stocks-solutions/data/GOOG.csv');

INSERT INTO PRICES (SYMBOL, PRICEDATE, OPEN, HIGH, LOW, CLOSE, VOLUME, ADJUSTEDCLOSE)
  SELECT 'INTC', convert(parsedatetime(date, 'yyyy-M-d'), date) as PRICEDATE,
    OPEN, HIGH, LOW, CLOSE, VOLUME, ADJCLOSE
  FROM csvread('C:/classes/JAX-RS/stocks-solutions/data/INTC.csv');

INSERT INTO PRICES (SYMBOL, PRICEDATE, OPEN, HIGH, LOW, CLOSE, VOLUME, ADJUSTEDCLOSE)
  SELECT 'INTU', convert(parsedatetime(date, 'yyyy-M-d'), date) as PRICEDATE,
    OPEN, HIGH, LOW, CLOSE, VOLUME, ADJCLOSE
  FROM csvread('C:/classes/JAX-RS/stocks-solutions/data/INTU.csv');

INSERT INTO PRICES (SYMBOL, PRICEDATE, OPEN, HIGH, LOW, CLOSE, VOLUME, ADJUSTEDCLOSE)
  SELECT 'MAR', convert(parsedatetime(date, 'yyyy-M-d'), date) as PRICEDATE,
    OPEN, HIGH, LOW, CLOSE, VOLUME, ADJCLOSE
  FROM csvread('C:/classes/JAX-RS/stocks-solutions/data/MAR.csv');

INSERT INTO PRICES (SYMBOL, PRICEDATE, OPEN, HIGH, LOW, CLOSE, VOLUME, ADJUSTEDCLOSE)
  SELECT 'QCOM', convert(parsedatetime(date, 'yyyy-M-d'), date) as PRICEDATE,
    OPEN, HIGH, LOW, CLOSE, VOLUME, ADJCLOSE
  FROM csvread('C:/classes/JAX-RS/stocks-solutions/data/QCOM.csv');

INSERT INTO PRICES (SYMBOL, PRICEDATE, OPEN, HIGH, LOW, CLOSE, VOLUME, ADJUSTEDCLOSE)
  SELECT 'SBUX', convert(parsedatetime(date, 'yyyy-M-d'), date) as PRICEDATE,
    OPEN, HIGH, LOW, CLOSE, VOLUME, ADJCLOSE
  FROM csvread('C:/classes/JAX-RS/stocks-solutions/data/SBUX.csv');

INSERT INTO PRICES (SYMBOL, PRICEDATE, OPEN, HIGH, LOW, CLOSE, VOLUME, ADJUSTEDCLOSE)
  SELECT 'VIAB', convert(parsedatetime(date, 'yyyy-M-d'), date) as PRICEDATE,
    OPEN, HIGH, LOW, CLOSE, VOLUME, ADJCLOSE
  FROM csvread('C:/classes/JAX-RS/stocks-solutions/data/VIAB.csv');

INSERT INTO PRICES (SYMBOL, PRICEDATE, OPEN, HIGH, LOW, CLOSE, VOLUME, ADJUSTEDCLOSE)
  SELECT 'YHOO', convert(parsedatetime(date, 'yyyy-M-d'), date) as PRICEDATE,
    OPEN, HIGH, LOW, CLOSE, VOLUME, ADJCLOSE
  FROM csvread('C:/classes/JAX-RS/stocks-solutions/data/YHOO.csv');
