package com.speedingplanet.equities.api;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonProperty;
import org.joda.time.DateTime;

import javax.persistence.*;
import javax.validation.constraints.NotNull;

@Entity
@Table(name = "orders")
@NamedQueries({
    @NamedQuery(
        name = "com.speedingplanet.equities.api.Order.findAll",
        query = "SELECT o from Order o"
    )
})
public class Order {

  @NotNull
  private int orderId;

  @NotNull
  private String symbol;

  @JsonFormat
      (shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd")
  private DateTime orderDate;

  @NotNull
  private int quantity;

  @NotNull
  private double price;

  private Security security;

  public Order() {}

  public Order(String symbol, DateTime orderDate, int quantity, double price) {
    this.symbol = symbol;
    this.orderDate = orderDate;
    this.quantity = quantity;
    this.price = price;
  }

  @Id
  @GeneratedValue(strategy = GenerationType.IDENTITY)
  public int getOrderId() {
    return orderId;
  }

  public void setOrderId(int orderId) {
    this.orderId = orderId;
  }

  public String getSymbol() {
    return symbol;
  }

  public void setSymbol(String symbol) {
    this.symbol = symbol;
  }

  public DateTime getOrderDate() {
    return orderDate;
  }

  public void setOrderDate(DateTime orderDate) {
    this.orderDate = orderDate;
  }

  public int getQuantity() {
    return quantity;
  }

  public void setQuantity(int quantity) {
    this.quantity = quantity;
  }

  public double getPrice() {
    return price;
  }

  public void setPrice(double price) {
    this.price = price;
  }

  // Join
  @ManyToOne(fetch = FetchType.EAGER, targetEntity = Security.class)
  @JoinColumn(name = "symbol", nullable = false, insertable = false, updatable = false)
  public Security getSecurity() {
    return security;
  }

  public void setSecurity(Security security) {
    this.security = security;
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) return true;
    if (!(o instanceof Order)) return false;

    Order order = (Order) o;

    if (getOrderId() != order.getOrderId()) return false;
    if (getQuantity() != order.getQuantity()) return false;
    if (Double.compare(order.getPrice(), getPrice()) != 0) return false;
    if (!getSymbol().equals(order.getSymbol())) return false;
    return getOrderDate().equals(order.getOrderDate());

  }

  @Override
  public int hashCode() {
    int result;
    long temp;
    result = getOrderId();
    result = 31 * result + getSymbol().hashCode();
    result = 31 * result + getOrderDate().hashCode();
    result = 31 * result + getQuantity();
    temp = Double.doubleToLongBits(getPrice());
    result = 31 * result + (int) (temp ^ (temp >>> 32));
    return result;
  }
}
