package com.speedingplanet.equities.api;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonProperty;
import org.joda.time.DateTime;

import javax.persistence.*;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Null;

@Entity
@Table(name = "positions")
@NamedQueries({
    @NamedQuery(
        name = "com.speedingplanet.equities.api.Position.findAll",
        query = "SELECT pos from Position pos"
    )
})
public class Position {

  @NotNull
  private int positionId;

  @NotNull
  private String symbol;

  @NotNull
  private int quantity;

  @NotNull
  private double boughtPrice;

  @JsonFormat
      (shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd")
  private DateTime boughtDate;

  @Null
  private Double soldPrice;

  @Null
  @JsonFormat
      (shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd")
  private DateTime soldDate;

  private boolean isActive;

  private Security security;

  public Position() {
  }

  public Position(int positionId, String symbol, int quantity, double boughtPrice, DateTime boughtDate) {
    this.positionId = positionId;
    this.symbol = symbol;
    this.quantity = quantity;
    this.boughtPrice = boughtPrice;
    this.boughtDate = boughtDate;
  }

  @Id
  @GeneratedValue(strategy = GenerationType.IDENTITY)
  public int getPositionId() {
    return positionId;
  }

  public void setPositionId(int positionId) {
    this.positionId = positionId;
  }

  public String getSymbol() {
    return symbol;
  }

  public void setSymbol(String symbol) {
    this.symbol = symbol;
  }

  public int getQuantity() {
    return quantity;
  }

  public void setQuantity(int quantity) {
    this.quantity = quantity;
  }

  public double getBoughtPrice() {
    return boughtPrice;
  }

  public void setBoughtPrice(double boughtPrice) {
    this.boughtPrice = boughtPrice;
  }

  public DateTime getBoughtDate() {
    return boughtDate;
  }

  public void setBoughtDate(DateTime boughtDate) {
    this.boughtDate = boughtDate;
  }

  @Column(nullable = true)
  public Double getSoldPrice() {
    return soldPrice;
  }

  public void setSoldPrice(Double soldPrice) {
    this.soldPrice = soldPrice;
  }

  @Column(nullable = true)
  public DateTime getSoldDate() {
    return soldDate;
  }

  public void setSoldDate(DateTime soldDate) {
    this.soldDate = soldDate;
  }

  @Column(name = "isActive")
  public boolean isActive() {

    return isActive;
  }

  @Column(name = "isActive")
  public void setActive(boolean active) {
    isActive = active;
  }

  // Join
  @ManyToOne(fetch = FetchType.EAGER, targetEntity = Security.class)
  @JoinColumn(name = "symbol", nullable = false, insertable = false, updatable = false)
  public Security getSecurity() {
    return security;
  }

  public void setSecurity(Security security) {
    this.security = security;
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) return true;
    if (!(o instanceof Position)) return false;

    Position position = (Position) o;

    return this.getPositionId() == position.getPositionId();
  }

  @Override
  public int hashCode() {
    int result;
    long temp;
    result = getPositionId();
    result = 31 * result + getSymbol().hashCode();
    result = 31 * result + getQuantity();
    temp = Double.doubleToLongBits(getBoughtPrice());
    result = 31 * result + (int) (temp ^ (temp >>> 32));
    result = 31 * result + getBoughtDate().hashCode();
    return result;
  }
}
