package com.speedingplanet.equities.api;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonProperty;
import org.hibernate.annotations.Type;
import org.joda.time.DateTime;

import javax.persistence.*;
import javax.validation.constraints.NotNull;

@Entity
@Table(name = "prices")
@NamedQueries({
    @NamedQuery(
        name = "com.speedingplanet.equities.api.Price.findAll",
        query = "SELECT p from Price p"
    )
})
public class Price {

  @NotNull
  private int priceId;

  @NotNull
  private String symbol;

  @JsonFormat
      (shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd")
  private DateTime priceDate;

  @NotNull
  private double open;

  @NotNull
  private double high;

  @NotNull
  private double low;

  @NotNull
  private double close;

  @NotNull
  private int volume;

  @NotNull
  private double adjustedClose;

  private Security security;

  public Price() {}

  public Price(String symbol, DateTime priceDate, double open, double high, double low, double close, int volume, double adjustedClose) {
    this.symbol = symbol;
    this.priceDate = priceDate;
    this.open = open;
    this.high = high;
    this.low = low;
    this.close = close;
    this.volume = volume;
    this.adjustedClose = adjustedClose;
  }

  @Id
  @GeneratedValue(strategy = GenerationType.IDENTITY)
  public int getPriceId() {
    return priceId;
  }

  public void setPriceId(int priceId) {
    this.priceId = priceId;
  }

  public String getSymbol() {
    return symbol;
  }

  public void setSymbol(String symbol) {
    this.symbol = symbol;
  }

  public DateTime getPriceDate() {
    return priceDate;
  }

  public void setPriceDate(DateTime priceDate) {
    this.priceDate = priceDate;
  }

  public double getOpen() {
    return open;
  }

  public void setOpen(double open) {
    this.open = open;
  }

  public double getHigh() {
    return high;
  }

  public void setHigh(double high) {
    this.high = high;
  }

  public double getLow() {
    return low;
  }

  public void setLow(double low) {
    this.low = low;
  }

  public double getClose() {
    return close;
  }

  public void setClose(double close) {
    this.close = close;
  }

  public int getVolume() {
    return volume;
  }

  public void setVolume(int volume) {
    this.volume = volume;
  }

  public double getAdjustedClose() {
    return adjustedClose;
  }

  public void setAdjustedClose(double adjustedClose) {
    this.adjustedClose = adjustedClose;
  }

  // Join
  @ManyToOne(fetch = FetchType.EAGER, targetEntity = Security.class)
  @JoinColumn(name = "symbol", nullable = false, insertable = false, updatable = false)
  public Security getSecurity() {
    return security;
  }

  public void setSecurity(Security security) {
    this.security = security;
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) return true;
    if (!(o instanceof Price)) return false;

    Price price = (Price) o;

    if (getPriceId() != price.getPriceId()) return false;
    if (Double.compare(price.getOpen(), getOpen()) != 0) return false;
    if (!getSymbol().equals(price.getSymbol())) return false;
    return getPriceDate().equals(price.getPriceDate());

  }

  @Override
  public int hashCode() {
    int result;
    long temp;
    result = getPriceId();
    result = 31 * result + getSymbol().hashCode();
    result = 31 * result + getPriceDate().hashCode();
    temp = Double.doubleToLongBits(getOpen());
    result = 31 * result + (int) (temp ^ (temp >>> 32));
    return result;
  }
}
