package com.speedingplanet.equities.api;

import com.fasterxml.jackson.annotation.JsonProperty;

import javax.persistence.*;
import javax.validation.constraints.NotNull;
import java.util.Set;

@Entity
@Table(name = "securities")
@NamedQueries({
    @NamedQuery(
        name = "com.speedingplanet.equities.api.Security.findAll",
        query = "SELECT sec from Security sec"
    )
})
public class Security {

  @NotNull
  private String symbol;

  @NotNull
  private String securityName;

  // For joins
  private Set<Order> orders;
  private Set<Position> positions;
  private Set<Price> prices;

  public Security() {
  }

  public Security(String symbol, String securityName) {
    this.symbol = symbol;
    this.securityName = securityName;
  }

  @Id
  public String getSymbol() {
    return symbol;
  }

  public void setSymbol(String symbol) {
    this.symbol = symbol;
  }

  public String getSecurityName() {
    return securityName;
  }

  public void setSecurityName(String securityName) {
    this.securityName = securityName;
  }

  @OneToMany(mappedBy = "security", fetch = FetchType.LAZY)
  public Set<Order> getOrders() {
    return orders;
  }

  public void setOrders(Set<Order> orders) {
    this.orders = orders;
  }

  @OneToMany(mappedBy = "security", fetch = FetchType.LAZY)
  public Set<Position> getPositions() {
    return positions;
  }

  public void setPositions(Set<Position> positions) {
    this.positions = positions;
  }

  @OneToMany(mappedBy = "security", fetch = FetchType.LAZY)
  public Set<Price> getPrices() {
    return prices;
  }

  public void setPrices(Set<Price> prices) {
    this.prices = prices;
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) return true;
    if (!(o instanceof Security)) return false;

    Security security = (Security) o;

    if (!getSymbol().equals(security.getSymbol())) return false;
    return securityName.equals(security.securityName);

  }

  @Override
  public int hashCode() {
    int result = getSymbol().hashCode();
    result = 31 * result + securityName.hashCode();
    return result;
  }
}
