package com.speedingplanet.equities.db;

import com.speedingplanet.equities.api.Order;
import com.speedingplanet.equities.api.Position;
import io.dropwizard.hibernate.AbstractDAO;
import org.hibernate.Criteria;
import org.hibernate.SessionFactory;
import org.hibernate.criterion.Restrictions;
import org.joda.time.DateTime;

import javax.ws.rs.core.MultivaluedMap;
import java.util.List;

public class OrderDAO extends AbstractDAO<Order> {

  public OrderDAO(SessionFactory sessionFactory) {
    super(sessionFactory);
  }

  public Order findById(int id) {
    return get(id);
  }

  public List<Order> findAll() {
    return list(namedQuery("com.speedingplanet.equities.api.Order.findAll"));
  }

  public List<Order> query(MultivaluedMap<String, String> queryParams) {
    Criteria c = criteria();

    for (String key : queryParams.keySet()) {
      switch (key) {
        case "orderId" :
        case "quantity" :
          c.add(Restrictions.eq(key, Integer.parseInt(queryParams.getFirst(key))));
          break;
        case "price":
          c.add(Restrictions.eq(key, Double.parseDouble(queryParams.getFirst(key))));
          break;
        case "orderDate" :
          c.add(Restrictions.eq(key, new DateTime(queryParams.getFirst(key))));
          break;
        case "priceGreaterThan" :
          c.add(Restrictions.ge("price", Double.parseDouble(queryParams.getFirst(key))));
          break;
        case "priceLessThan":
          c.add(Restrictions.le("price", Double.parseDouble(queryParams.getFirst(key))));
          break;
        case "quantityGreaterThan":
          c.add(Restrictions.ge("quantity", Integer.parseInt(queryParams.getFirst(key))));
          break;
        case "quantityLessThan":
          c.add(Restrictions.le("quantity", Integer.parseInt(queryParams.getFirst(key))));
          break;
        case "orderBefore" :
          c.add(Restrictions.le("order", new DateTime(queryParams.getFirst(key))));
          break;
        case "orderAfter" :
          c.add(Restrictions.ge("order", new DateTime(queryParams.getFirst(key))));
          break;
      }
    }

    return list(c);
  }

  public Order update(Order o) {
    return persist(o);
  }

  public Order create(Order o) {
    return persist(o);
  }

}
