package com.speedingplanet.equities.db;

import com.speedingplanet.equities.api.Position;
import io.dropwizard.hibernate.AbstractDAO;
import org.hibernate.Criteria;
import org.hibernate.SessionFactory;
import org.hibernate.criterion.Restrictions;
import org.joda.time.DateTime;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.ws.rs.core.MultivaluedMap;
import java.util.Date;
import java.util.List;

public class PositionDAO extends AbstractDAO<Position> {
  private static final Logger LOGGER = LoggerFactory.getLogger(PositionDAO.class);

  public PositionDAO(SessionFactory sessionFactory) {
    super(sessionFactory);
  }

  public Position findById(int id) {
    return get(id);
  }

  public List<Position> findAll() {
    return list(namedQuery("com.speedingplanet.equities.api.Position.findAll"));
  }

  public List<Position> query(MultivaluedMap<String, String> queryParams) {
    Criteria c = criteria();

    if (queryParams.containsKey("isActive")) {
      c.add(Restrictions.eq("isActive", queryParams.getFirst("isActive")));
    } else {
      c.add(Restrictions.eq("isActive", true));
    }

    for (String key : queryParams.keySet()) {
      switch (key) {
        case "positionId":
        case "quantity" :
          c.add(Restrictions.eq(key, Integer.parseInt(queryParams.getFirst(key))));
          break;
        case "boughtDate":
        case "soldDate":
          c.add(Restrictions.eq(key, new DateTime(queryParams.getFirst(key))));
          break;
        case "symbol":
          c.add(Restrictions.in("symbol", queryParams.get(key)));
          break;
        case "boughtBefore":
        case "soldBefore":
          c.add(Restrictions.le(key.startsWith("bought") ? "boughtDate" : "soldDate", new DateTime(queryParams.getFirst(key))));
          break;
        case "boughtAfter":
        case "soldAfter":
          c.add(Restrictions.ge(key.startsWith("bought") ? "boughtDate" : "soldDate", new DateTime(queryParams.getFirst(key))));
          break;
        case "boughtPriceGreaterThan" :
        case "soldPriceGreaterThan" :
          c.add(Restrictions.ge(key.startsWith("bought") ? "boughtPrice" : "soldPrice", Double.parseDouble(key)));
          break;
        case "boughtPriceLessThan" :
        case "soldPriceLessThan" :
          c.add(Restrictions.le(key.startsWith("bought") ? "boughtPrice" : "soldPrice", Double.parseDouble(key)));
          break;

      }
    }

    return list(c);
  }

  public Position update(Position p) {
    return persist(p);
  }

  public Position create(Position p) {
    return persist(p);
  }

}
