package com.speedingplanet.equities.db;

import com.speedingplanet.equities.api.Price;
import io.dropwizard.hibernate.AbstractDAO;
import org.hibernate.Criteria;
import org.hibernate.SessionFactory;
import org.hibernate.criterion.Restrictions;
import org.joda.time.DateTime;

import javax.ws.rs.core.MultivaluedMap;
import java.util.List;

public class PriceDAO extends AbstractDAO<Price> {

  public PriceDAO(SessionFactory sessionFactory) {
    super(sessionFactory);
  }

  public Price findById(int id) {
    return get(id);
  }

  public List<Price> findAll() {
    return list(namedQuery("com.speedingplanet.equities.api.Price.findAll"));
  }

  public List<Price> query(MultivaluedMap<String, String> queryParams) {
    Criteria c = criteria();

    // Start-date / end-date
    if (queryParams.containsKey("startDate")) {
      c.add(Restrictions.ge("priceDate", new DateTime(queryParams.getFirst("startDate"))));
    }

    if (queryParams.containsKey("endDate")) {
      c.add(Restrictions.le("priceDate", new DateTime(queryParams.getFirst("endDate"))));
    }

    if (queryParams.containsKey("symbol")) {
      c.add(Restrictions.eq("symbol", queryParams.getFirst("symbol")));
    }

    if (queryParams.containsKey("priceLow")) {
      c.add(Restrictions.ge("adjustedClose", queryParams.getFirst("priceLow")));
    }

    if (queryParams.containsKey("priceHigh")) {
      c.add(Restrictions.le("adjustedClose", queryParams.getFirst("priceHigh")));
    }

    return list(c);
  }
}
