package com.speedingplanet.equities.resources;

import com.google.common.base.Optional;
import com.speedingplanet.equities.api.Position;
import com.speedingplanet.equities.api.Price;
import com.speedingplanet.equities.db.PositionDAO;
import io.dropwizard.hibernate.UnitOfWork;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.validation.Valid;
import javax.ws.rs.*;
import javax.ws.rs.core.*;
import java.net.URI;
import java.util.List;

@Path("/position")
@Produces(MediaType.APPLICATION_JSON)
@Consumes(MediaType.APPLICATION_JSON)
public class PositionResource {
  private static final Logger LOGGER = LoggerFactory.getLogger(PositionResource.class);
  private final PositionDAO posDAO;

  @Context
  UriInfo uriInfo;

  public PositionResource(PositionDAO posDAO) {
    this.posDAO = posDAO;
  }

  @GET
  @UnitOfWork
  public List<Position> getPositions(@Context UriInfo uriInfo) {

    MultivaluedMap<String, String> queryParams = uriInfo.getQueryParameters();

    if (queryParams.size() == 0) {
      return posDAO.findAll();
    } else {
      return posDAO.query(queryParams);
    }
  }

  @Path("/{positionId:[0-9]+}")
  @GET
  @UnitOfWork
  public Position getPosition(@PathParam("positionId") int id) {
    Optional<Position> position = Optional.fromNullable(posDAO.findById(id));

    if (!position.isPresent()) {
      throw new NotFoundException(String.format("Position for positionId %d not found.", id));
    }
    return position.get();
  }

  @POST
  @UnitOfWork
  public Response insertPosition(Position pos) {
    if (pos.getPositionId() != 0) {
      LOGGER.warn("Attempted to insert Position with a positionId, rejected.");

      // 422 is an Unprocessable entity
      throw new WebApplicationException("Attempted to insert Position with a positionId, rejected.",
          422);
    }

    Position responsePos = posDAO.create(pos);
    URI uri = uriInfo
        .getBaseUriBuilder()
        .path(PositionResource.class)
        .path("" + responsePos.getPositionId())
        .build();
    return Response.created(uri).entity(responsePos).build();
  }

  @Path("/{positionId:[0-9]+}")
  @POST
  @UnitOfWork
  public Response updatePosition(Position pos) {
    if (pos.getPositionId() == 0) {
      throw new WebApplicationException("Attempted to update a Position without a positionId, rejected.",
          Response.Status.CONFLICT);
    }

    return Response.ok(posDAO.update(pos)).build();
  }

  @Path("/{positionId:[0-9]+}")
  @PUT
  @UnitOfWork
  public Response putUpdatePosition(Position pos) {
    return updatePosition(pos);
  }
}
