package com.speedingplanet.equities;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.speedingplanet.equities.api.Position;
import io.dropwizard.client.JerseyClientBuilder;
import io.dropwizard.client.JerseyClientConfiguration;
import io.dropwizard.db.DataSourceFactory;
import io.dropwizard.jackson.Jackson;
import io.dropwizard.testing.ResourceHelpers;
import io.dropwizard.testing.junit.DropwizardAppRule;
import io.dropwizard.util.Duration;
import org.h2.tools.RunScript;
import org.junit.After;
import org.junit.Before;
import org.junit.Rule;
import org.junit.Test;

import javax.ws.rs.client.Client;
import javax.ws.rs.client.Entity;
import javax.ws.rs.client.WebTarget;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.sql.SQLException;

import static io.dropwizard.testing.FixtureHelpers.fixture;
import static org.assertj.core.api.Assertions.assertThat;

public class PositionInsertUpdateIntegrationTest {
  private WebTarget baseTarget;
  private Client client;
  private static final ObjectMapper MAPPER = Jackson.newObjectMapper();

  // Multiple tests (below) means that this should be a Rule, not a ClassRule
  // per https://github.com/dropwizard/dropwizard/issues/832
  @Rule
  public final DropwizardAppRule<StocksConfiguration> RULE =
      new DropwizardAppRule<>(StocksApplication.class, ResourceHelpers.resourceFilePath("test-config.yml"));

  @Before
  public void setup() throws FileNotFoundException, SQLException {
    JerseyClientConfiguration jcc = new JerseyClientConfiguration();
    jcc.setTimeout(Duration.milliseconds(5000));
    jcc.setConnectionTimeout(Duration.milliseconds(5000));
    client = new JerseyClientBuilder(RULE.getEnvironment())
        .using(jcc)
        .build("test client");

    baseTarget = client.target(String.format("http://localhost:%d/equities", RULE.getLocalPort()));

    DataSourceFactory ds = RULE.getConfiguration().getDataSourceFactory();
    String user = ds.getUser();
    String pass = ds.getPassword();
    String url = ds.getUrl();
    RunScript.execute(url, user, pass, "sql/test-setup.sql", null, false);
  }

  @After
  public void shutdown() {
    client.close();
  }

  @Test
  public void addPos() throws IOException {
    Position newPos = MAPPER.readValue(fixture("fixtures/insert-position.json"), Position.class);
    Position checkPos = insertPos(newPos);

    assertThat(checkPos.getQuantity()).isEqualTo(newPos.getQuantity());
    assertThat(checkPos.getBoughtDate()).isEqualTo(newPos.getBoughtDate());
    assertThat(checkPos.getBoughtPrice()).isEqualTo(newPos.getBoughtPrice());
    assertThat(checkPos.getSymbol()).isEqualTo(newPos.getSymbol());
  }

  private Position insertPos(Position inTx) {
    Entity<Position> jsonEntity = Entity.entity(inTx, MediaType.APPLICATION_JSON);
    Response response = baseTarget
        .path("/position")
        .request(MediaType.APPLICATION_JSON_TYPE)
        .accept(MediaType.APPLICATION_JSON_TYPE)
        .post(jsonEntity);
    assertThat(response.getStatusInfo()).isEqualTo(Response.Status.CREATED);
    return response.readEntity(Position.class);
  }

}
