package com.speedingplanet.equities.resources;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.type.CollectionType;
import com.speedingplanet.equities.api.Security;
import com.speedingplanet.equities.db.SecurityDAO;
import io.dropwizard.jackson.Jackson;
import io.dropwizard.testing.junit.ResourceTestRule;
import org.junit.*;
import org.junit.runner.RunWith;
import org.mockito.ArgumentCaptor;
import org.mockito.Captor;
import org.mockito.runners.MockitoJUnitRunner;

import javax.ws.rs.core.GenericType;
import javax.ws.rs.core.MultivaluedHashMap;
import javax.ws.rs.core.MultivaluedMap;
import java.io.IOException;
import java.util.List;

import static io.dropwizard.testing.FixtureHelpers.fixture;
import static org.assertj.core.api.Assertions.assertThat;
import static org.mockito.Mockito.*;

@RunWith(MockitoJUnitRunner.class)
public class SecurityResourceTest {
  private static final ObjectMapper MAPPER = Jackson.newObjectMapper();
  private static final SecurityDAO dao = mock(SecurityDAO.class);

  @ClassRule
  public static final ResourceTestRule resources = ResourceTestRule.builder()
      .addResource(new SecurityResource(dao))
      .build();

  @Captor
  ArgumentCaptor<Security> secCaptor;

  @Before
  public void setup() {

  }

  @After
  public void tearDown() {
    reset(dao);
  }

  @Test
  public void testGetSecurity() {
    final Security security = new Security("AAPL", "Apple Computer");
    when(dao.findBySymbol(security.getSymbol())).thenReturn(security);

    assertThat(resources.client().target("/security/AAPL").request().get(Security.class))
    .isEqualTo(security);
    verify(dao).findBySymbol("AAPL");
  }

  @Test
  public void testGetSecurities() throws IOException {
    // Mocked data
    Security sec = MAPPER.readValue(fixture("fixtures/security.json"), Security.class);

    // Mocked response
    when(dao.findBySymbol("SEAS")).thenReturn(sec);

    assertThat(resources.client().target("/security/SEAS").request().get(Security.class))
        .isEqualTo(sec);
    verify(dao).findBySymbol("SEAS");
  }
}
